netapp_ontap.models.fpolicy_policies_scope API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.fpolicy_policies_scope`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class FpolicyPoliciesScopeSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the FpolicyPoliciesScope object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `check_extensions_on_directories: bool GET POST PATCH`

    Specifies whether the file name extension checks also apply to directory objects. If this parameter is set to true, the directory objects are subjected to the same extension checks as regular files. If this parameter is set to false, the directory names are not matched for extensions and notifications are sent for directories even if their name extensions do not match. Default is false.

  `exclude_export_policies: List[str] GET POST PATCH`

    The exclude_export_policies field of the fpolicy_policies_scope.

  `exclude_extension: List[str] GET POST PATCH`

    The exclude_extension field of the fpolicy_policies_scope.

  `exclude_shares: List[str] GET POST PATCH`

    The exclude_shares field of the fpolicy_policies_scope.

  `exclude_volumes: List[str] GET POST PATCH`

    The exclude_volumes field of the fpolicy_policies_scope.

    Example: ["vol1","vol_svm1","*"]

  `include_export_policies: List[str] GET POST PATCH`

    The include_export_policies field of the fpolicy_policies_scope.

  `include_extension: List[str] GET POST PATCH`

    The include_extension field of the fpolicy_policies_scope.

  `include_shares: List[str] GET POST PATCH`

    The include_shares field of the fpolicy_policies_scope.

    Example: ["sh1","share_cifs"]

  `include_volumes: List[str] GET POST PATCH`

    The include_volumes field of the fpolicy_policies_scope.

    Example: ["vol1","vol_svm1"]

  `object_monitoring_with_no_extension: bool GET POST PATCH`

    Specifies whether the extension checks also apply to objects with no extension. If this parameter is set to true, all objects with or without extensions are monitored. Default is false.